Functions Mixed-Up Code Questions
----------------------------------

.. selectquestion:: Functions_MixedUpCode_1_sq
   :fromid: Functions_MixedUpCode_1P_v2, Functions_MixedUpCode_1P_v2_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_2_sq
   :fromid: Functions_MixedUpCode_2, Functions_MixedUpCode_2_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_3_sq
   :fromid: Functions_MixedUpCode_3, Functions_MixedUpCode_3_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_4_sq
   :fromid: Functions_MixedUpCode_4, Functions_MixedUpCode_4_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_5_sq
   :fromid: Functions_MixedUpCode_5, Functions_MixedUpCode_5_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_6_sq
   :fromid: Functions_MixedUpCode_6, Functions_MixedUpCode_6_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_7_sq
   :fromid: Functions_MixedUpCode_7, Functions_MixedUpCode_7_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_8_sq
   :fromid: Functions_MixedUpCode_8, Functions_MixedUpCode_8_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_9_sq
   :fromid: Functions_MixedUpCode_9, Functions_MixedUpCode_9_ac
   :toggle:

.. selectquestion:: Functions_MixedUpCode_10_sq
   :fromid: Functions_MixedUpCode_10, Functions_MixedUpCode_10_ac
   :toggle: